pub struct ContainerdStep { /* private fields */ }Expand description
Containerdstep.
Implementations
Sourceimpl ContainerdStep
impl ContainerdStep
pub fn new(config: ContainerdConfig) -> Self
Sourcepub async fn run_service(
addr: &str,
container_id: &str,
image: &str,
env: &HashMap<String, String>,
) -> Result<(), WfeError>
pub async fn run_service( addr: &str, container_id: &str, image: &str, env: &HashMap<String, String>, ) -> Result<(), WfeError>
Start a long-running service container via the containerd gRPC API.
Used by ContainerdServiceProvider to provision infrastructure services.
The container runs on the host network so its ports are accessible on 127.0.0.1.
Unlike step execution, this does NOT wait for the container to exit.
Sourcepub async fn cleanup_service(
addr: &str,
container_id: &str,
) -> Result<(), WfeError>
pub async fn cleanup_service( addr: &str, container_id: &str, ) -> Result<(), WfeError>
Stop and clean up a service container via the containerd gRPC API.